pub struct EventLoop<T: 'static> { /* private fields */ }Expand description
Provides a way to retrieve events from the system and from the windows that were registered to the events loop.
An EventLoop can be seen more or less as a “context”. Calling EventLoop::new()
initializes everything that will be required to create windows.
To wake up an EventLoop from a another thread, see the EventLoopProxy docs.
Note that the EventLoop cannot be shared across threads (due to platform-dependant logic
forbidding it), as such it is neither Send nor Sync. If you need cross-thread access, the
Window created from this EventLoop can be sent to an other thread, and the
EventLoopProxy allows you to wake up an EventLoop from another thread.
Implementations
Sourceimpl EventLoop<()>
impl EventLoop<()>
Sourcepub fn new() -> EventLoop<()>
pub fn new() -> EventLoop<()>
Alias for EventLoopBuilder::new().build().
Sourceimpl<T> EventLoop<T>
impl<T> EventLoop<T>
Sourcepub fn run<F>(self, event_handler: F) -> !
pub fn run<F>(self, event_handler: F) -> !
Hijacks the calling thread and initializes the tao event loop with the provided
closure. Since the closure is 'static, it must be a move closure if it needs to
access any data from the calling context.
See the ControlFlow docs for information on how changes to &mut ControlFlow impact the
event loop’s behavior.
Any values not passed to this function will not be dropped.
Platform-specific
- Unix: The program terminates with exit code 1 if the display server disconnects.
Sourcepub fn create_proxy(&self) -> EventLoopProxy<T>
pub fn create_proxy(&self) -> EventLoopProxy<T>
Creates an EventLoopProxy that can be used to dispatch user events to the main event loop.
Methods from Deref<Target = EventLoopWindowTarget<T>>
Sourcepub fn available_monitors(&self) -> impl Iterator<Item = MonitorHandle>
pub fn available_monitors(&self) -> impl Iterator<Item = MonitorHandle>
Returns the list of all the monitors available on the system.
Sourcepub fn primary_monitor(&self) -> Option<MonitorHandle>
pub fn primary_monitor(&self) -> Option<MonitorHandle>
Returns the primary monitor of the system.
Returns None if it can’t identify any monitor as a primary one.
Sourcepub fn monitor_from_point(&self, x: f64, y: f64) -> Option<MonitorHandle>
pub fn monitor_from_point(&self, x: f64, y: f64) -> Option<MonitorHandle>
Sourcepub fn set_device_event_filter(&self, _filter: DeviceEventFilter)
pub fn set_device_event_filter(&self, _filter: DeviceEventFilter)
Change DeviceEvent filter mode.
Since the DeviceEvent capture can lead to high CPU usage for unfocused windows, tao
will ignore them by default for unfocused windows. This method allows changing
this filter at runtime to explicitly capture them again.
Platform-specific
- Linux / macOS / iOS / Android: Unsupported.
Sourcepub fn cursor_position(&self) -> Result<PhysicalPosition<f64>, ExternalError>
pub fn cursor_position(&self) -> Result<PhysicalPosition<f64>, ExternalError>
Returns the current cursor position
Platform-specific
- iOS / Android / Linux(Wayland): Unsupported, returns
0,0.
Sourcepub fn set_progress_bar(&self, _progress: ProgressBarState)
pub fn set_progress_bar(&self, _progress: ProgressBarState)
Sets the progress bar state
Platform-specific
- Windows: Unsupported. Use the Progress Bar Function Available in Window (Windows can have different progress bars for different window)
- Linux: Only supported desktop environments with
libunity(e.g. GNOME). - iOS / Android: Unsupported.