pub struct WindowAttributes {Show 22 fields
pub inner_size: Option<Size>,
pub inner_size_constraints: WindowSizeConstraints,
pub position: Option<Position>,
pub resizable: bool,
pub minimizable: bool,
pub maximizable: bool,
pub closable: bool,
pub fullscreen: Option<Fullscreen>,
pub title: String,
pub maximized: bool,
pub visible: bool,
pub transparent: bool,
pub decorations: bool,
pub always_on_top: bool,
pub always_on_bottom: bool,
pub window_icon: Option<Icon>,
pub preferred_theme: Option<Theme>,
pub focused: bool,
pub focusable: bool,
pub content_protection: bool,
pub visible_on_all_workspaces: bool,
pub background_color: Option<RGBA>,
}Expand description
Attributes to use when creating a window.
Fields
inner_size: Option<Size>The dimensions of the window. If this is None, some platform-specific dimensions will be
used.
The default is None.
inner_size_constraints: WindowSizeConstraintsThe window size constraints
position: Option<Position>The desired position of the window. If this is None, some platform-specific position
will be chosen.
The default is None.
Platform-specific
- macOS: The top left corner position of the window content, the window’s “inner”
position. The window title bar will be placed above it.
The window will be positioned such that it fits on screen, maintaining
set
inner_sizeif any. If you need to precisely position the top left corner of the whole window you have to useWindow::set_outer_positionafter creating the window. - Windows: The top left corner position of the window title bar, the window’s “outer” position. There may be a small gap between this position and the window due to the specifics of the Window Manager.
- Linux: The top left corner of the window, the window’s “outer” position.
- Linux(Wayland): Unsupported.
- Others: Ignored.
resizable: boolWhether the window is resizable or not.
The default is true.
minimizable: boolWhether the window is minimizable or not.
The default is true.
See Window::set_minimizable for details.
maximizable: boolWhether the window is maximizable or not.
The default is true.
See Window::set_maximizable for details.
closable: boolfullscreen: Option<Fullscreen>Whether the window should be set as fullscreen upon creation.
The default is None.
title: StringThe title of the window in the title bar.
The default is "tao window".
maximized: boolWhether the window should be maximized upon creation.
The default is false.
visible: boolWhether the window should be immediately visible upon creation.
The default is true.
transparent: boolWhether the the window should be transparent. If this is true, writing colors
with alpha values different than 1.0 will produce a transparent window.
The default is false.
decorations: boolWhether the window should have borders and bars.
The default is true.
always_on_top: boolWhether the window should always be on top of other windows.
The default is false.
Platform-specific:
- Linux(x11): Result depends on the system’s window manager. Consider this setting a suggestion.
- Linux(Wayland): Unsupported.
always_on_bottom: boolWhether the window should always be on bottom of other windows.
The default is false.
Platform-specific:
- Linux(x11): Result depends on the system’s window manager. Consider this setting a suggestion.
- Linux(Wayland): Unsupported.
window_icon: Option<Icon>The window icon.
The default is None.
preferred_theme: Option<Theme>focused: boolWhether the window should be initially focused or not.
Platform-specific:
Android / iOS: Unsupported.
focusable: boolcontent_protection: boolPrevents the window contents from being captured by other apps.
Platform-specific
- iOS / Android / Linux: Unsupported.
visible_on_all_workspaces: boolSets whether the window should be visible on all workspaces.
Platform-specific
- iOS / Android / Windows: Unsupported.
background_color: Option<RGBA>Sets the window background color.
Platform-specific:
- Windows: alpha channel is ignored. Instead manually draw the window, for example using
softbuffercrate, see https://github.com/tauri-apps/tao/blob/dev/examples/transparent.rs - iOS / Android: Unsupported.